#!/usr/bin/env python
# coding: utf-8

import json
from dsFramework.base.pipeline.artifacts.shared_artifacts import ZIDS_SharedArtifacts

class generatedClass(ZIDS_SharedArtifacts):

    def __init__(self) -> None:
        super().__init__()

    def load_vocabs(self):
        pass

    def load_artifacts(self):
        pass
